{% extends 'base.html' %}{% load i18n %}


{% block content %}
<p>{% trans 'Registration successful.' %}</p>
<p>{% trans 'Please check your email inbox for instructions on how to activate your account.' %}</p>
{% endblock content %}
